@@ -6,6 +6,7 @@
 
 import inspect
 import json
+import time
 from datetime import datetime
 from typing import Optional, Awaitable, Any
 
@@ -32,6 +33,8 @@ class BaseHandler(RequestHandler):
         :param kwargs:
         """
         # 如果想要使用自定义响应，设置self.original为True
+        self.start_time = time.time()
+        self.end_time = time.time()
         self.original = False
         super().__init__(application, request, **kwargs)
 
@@ -93,6 +96,8 @@ class BaseHandler(RequestHandler):
             else:
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
+            self.end_time = time.time()
+            self.set_header("ApiTime", self.end_time - self.start_time)
             if not self.original:
                 self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
@@ -180,6 +185,8 @@ class BaseHandler(RequestHandler):
             else:
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
+            self.end_time = time.time()
+            self.set_header("ApiTime", self.end_time - self.start_time)
             if not self.original:
                 self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
@@ -196,6 +203,7 @@ class BaseHandler(RequestHandler):
         else:
             self.set_header("Access-Control-Allow-Origin", "*")
         self.set_header("requestID", self.request.headers.get("requestID", ""))
+        self.set_header("pluginRunningTime", self.request.headers.get("pluginRunningTime", ""))
         self.set_header("Access-Control-Allow-Headers", "x-requested-with,Authorization,Can-read-cache")
         self.set_header("Access-Control-Allow-Methods", "POST,GET,PUT,DELETE,OPTIONS")
         self.set_header("Access-Control-Expose-Headers", "Access-Token")
